# exopie
Find exoplanet interior structure error (exopie), given mass and radius of the planet.

The methodology is described in Plotnykov & Valencia (2024) and is based on the SUPEREARTH interior structure model developed by Valencia et al. [(2006)](https://www.sciencedirect.com/science/article/abs/pii/S0019103505004574?via%3Dihub) and 
updated in Plotnykov & Valencia [(2020)](https://academic.oup.com/mnras/article/499/1/932/5899063). 

## Features
* Find the core mass fraction (CMF) of a rocky planet.
* Find the water mass fraction (WMF) of a temperate water world (Teq=300K).
* Find the atmospheric mass fraction (AMF) of a H_2/He dominated sub-Neptune (beta).

## Installation

```ssh
pip install exopie
```

## Citation
Please cite Plotnykov & Valencia (2024) if you use this code or parts of SUPEREARTH.
